@@ -1,13 +1,12 @@
 """The Pythonic Archive Kit"""
 from .utils import __VERSION_STR__
 
-from . import mini_pak
+from . import base
 
 try:
     from . import pak
-    
 except ImportError:
-    pak = mini_pak
+    from . import base as pak
     print(
         "WARNING: cryptography is not installed. PAK files will not be encrypted.", 
         "To install cryptography, run `pip install cryptography`", 
